.. ZZU.Py documentation master file, created by
   sphinx-quickstart on Fri Dec 13 19:16:10 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

ZZU.Py 文档
====================

郑州大学移动校园的 Python API 封装


.. toctree::
   :maxdepth: 3
   :caption: Contents:

API Base
=================

.. automodule:: api
   :members:
   :undoc-members:
   :show-inheritance:

Supwisdom
=================

.. automodule:: supwisdom
   :members:
   :undoc-members:
   :show-inheritance:

eCard
=================

.. automodule:: ecard
   :members:
   :undoc-members:
   :show-inheritance:

Network
=================

.. automodule:: network
   :members:
   :undoc-members:
   :show-inheritance:

